@@ -1,5 +1,11 @@
 # frozen_string_literal: true
 
+proc do
+  old_verbose, $VERBOSE = $VERBOSE, nil
+  require 'bigdecimal' # eagerly require bigdecimal without warnings to avoid warning caused by ttfunk 1.7.0
+  $VERBOSE = old_verbose
+end.call
+
 autoload :Set, 'set'
 autoload :StringIO, 'stringio'
 autoload :Tempfile, 'tempfile'
