@@ -4,7 +4,7 @@ Prawn::Font::AFM.instance_variable_set :@hide_m17n_warning, true
 
 require 'prawn/icon'
 
-Prawn::Icon::Compatibility.prepend (::Module.new { def warning *_args; end })
+Prawn::Icon::Compatibility.prepend (Module.new { def warning *_args; end })
 
 module Asciidoctor
   module Prawn
@@ -1002,9 +1002,16 @@ module Asciidoctor
       # start_new_page. Using start_new_page can mangle the calculation of content block's extent.
       #
       def arrange_block node, &block
-        keep_together = (node.option? 'unbreakable') && !at_page_top?
+        if at_page_top?
+          at_top = true
+        else
+          at_top = true if node.first_child? && (node.parent.attr? 'pdf-at-top')
+          keep_together = true if node.option? 'unbreakable'
+        end
+        node.set_attr 'pdf-at-top', '' if at_top
         doc = node.document
         block_for_scratch = proc do
+          at_top = node.set_attr 'pdf-at-top', '' if !at_top && at_page_top?
           push_scratch doc
           instance_exec(&block)
         ensure
@@ -1012,6 +1019,8 @@ module Asciidoctor
         end
         extent = dry_run keep_together: keep_together, onto: [self, keep_together], &block_for_scratch
         scratch? ? block_for_scratch.call : (yield extent)
+      ensure
+        node.remove_attr 'pdf-at-top' if at_top
       end
 
       # This method installs an on_page_create_callback that stops processing if the first page is
