@@ -24,9 +24,9 @@ module Asciidoctor
           if FormattingSnifferPattern.match? string
             if (parsed = @parser.parse string)
               return @transform.apply parsed.content, [], inherited
-            elsif !@scratch
-              logger.error %(failed to parse formatted text: #{string})
             end
+            reason = @parser.failure_reason.sub %r/ at line \d+, column \d+ \(byte (\d+)\)(.*)/, '\2 at byte \1'
+            logger.error %(failed to parse formatted text: #{string} (reason: #{reason})) unless @scratch
           end
           [inherited ? (inherited.merge text: string) : { text: string }]
         end
