@@ -6,9 +6,12 @@ require 'rghost/gs_alone'
 require 'tmpdir'
 autoload :Open3, 'open3'
 
+# rghost still uses File.exists?
+File.singleton_class.alias_method :exists?, :exist? unless File.respond_to? :exists?
+
 RGhost::GSAlone.prepend (Module.new do
   def initialize params, debug
-    (@params = params.dup).push(*(@params.pop.split File::PATH_SEPARATOR))
+    (@params = params.drop 0).push(*(@params.pop.split File::PATH_SEPARATOR))
     @debug = debug
   end
 
