@@ -35,7 +35,7 @@ describe 'Asciidoctor::PDF::Converter - Cover Page' do
 
   it 'should add front cover page if front-cover-image attribute is set to data URI' do
     image_data = File.binread fixture_file 'cover.jpg'
-    encoded_image_data = Base64.strict_encode64 image_data
+    encoded_image_data = [image_data].pack 'm0'
     pdf = to_pdf <<~EOS
     = Document Title
     :front-cover-image: image:data:image/jpg;base64,#{encoded_image_data}[]
@@ -187,7 +187,7 @@ describe 'Asciidoctor::PDF::Converter - Cover Page' do
 
   it 'should add back cover page if back-cover-image attribute is set to data URI' do
     image_data = File.binread fixture_file 'cover.jpg'
-    encoded_image_data = Base64.strict_encode64 image_data
+    encoded_image_data = [image_data].pack 'm0'
     pdf = to_pdf <<~EOS
     = Document Title
     :front-cover-image: image:data:image/jpg;base64,#{encoded_image_data}[]
