@@ -38,7 +38,7 @@ describe 'Asciidoctor::PDF::Converter - TOC' do
       (expect pdf.find_text 'Introduction', page_number: 3).not_to be_empty
     end
 
-    it 'should space items in toc evently even if title is entirely monospace' do
+    it 'should space items in toc evenly even if title is entirely monospace' do
       pdf = to_pdf <<~'EOS', doctype: :book, analyze: true
       = Document Title
       :toc:
@@ -180,6 +180,35 @@ describe 'Asciidoctor::PDF::Converter - TOC' do
       (expect pdf.find_text page_number: 2, string: 'Appendix Section').to have_size 0
     end
 
+    it 'should include dot leaders in TOC entry if toclevels is increased for a given section' do
+      pdf = to_pdf <<~'EOS', analyze: true
+      = Document Title
+      :doctype: book
+      :toc:
+      :toclevels: 1
+
+      == Chapter
+
+      === Chapter Section
+
+      ==== Chapter Subsection
+
+      [toclevels=3]
+      == Lorem Ipsum
+
+      === Lorem Ipsum Section
+
+      ==== Lorem Ipsum Subsection
+      EOS
+
+      toc_lines = pdf.lines pdf.find_text page_number: 2
+      (expect toc_lines).to have_size 5
+      (expect toc_lines[1]).to match %r/^Chapter (\. )+.*?1/
+      (expect toc_lines[2]).to match %r/^Lorem Ipsum (\. )+.*?2/
+      (expect toc_lines[3]).to match %r/^Lorem Ipsum Section (\. )+.*?2/
+      (expect toc_lines[4]).to match %r/^Lorem Ipsum Subsection (\. )+.*?2/
+    end
+
     it 'should allow section to remove itself from toc by setting toclevels to less than section level' do
       pdf = to_pdf <<~'EOS', analyze: true
       = Document Title
@@ -352,7 +381,7 @@ describe 'Asciidoctor::PDF::Converter - TOC' do
       (expect toc_entry[:dest][:label]).to eql '2'
     end
 
-    it 'should not toc at default location if document has no sections' do
+    it 'should not insert toc at default location if document has no sections' do
       pdf = to_pdf <<~'EOS', analyze: true
       = Document Title
       :toc:
@@ -1575,6 +1604,30 @@ describe 'Asciidoctor::PDF::Converter - TOC' do
     (expect images[0][:width]).to eql images[1][:width]
   end
 
+  it 'should remove links from entries in toc but leave behind linked text' do
+    pdf = to_pdf <<~'EOS'
+    = Document Title
+    :doctype: book
+    :toc:
+
+    [#ch1]
+    == https://example.org[Once] Upon a https://example.com[Time]
+
+    [#ch2]
+    == Continuing What <<ch1>> Started
+    EOS
+
+    (expect pdf.pages).to have_size 4
+    toc_lines = ((pdf.page 2).text.split ?\n).reject(&:empty?)
+    (expect toc_lines).to have_size 3
+    (expect toc_lines[0]).to eql 'Table of Contents'
+    (expect toc_lines[1]).to start_with 'Once Upon a Time'
+    (expect toc_lines[2]).to start_with 'Continuing What Once Upon a Time Started'
+    annots = get_annotations pdf, 2
+    (expect annots).to have_size 4
+    (expect annots.map {|it| it[:Dest] }.sort).to eql %w(ch1 ch1 ch2 ch2)
+  end
+
   it 'should allow extended converter to insert extra page before toc' do
     backend = nil
     create_class (Asciidoctor::Converter.for 'pdf') do
